Internal helper function that fills NA values from columns with values from the nearest neighbouring points.
Source:R/extract_point_pixels.R
fill_na_nearest.RdInternal helper function that fills NA values from columns with values from the nearest neighbouring points.