Internal helper to compute the sum of square distances within cluster nodes. Follows spdep function, implementing igraph methods. For additional information see spdep::ssw
Source:R/fast_skater.R
ssw.RdInternal helper to compute the sum of square distances within cluster nodes. Follows spdep function, implementing igraph methods. For additional information see spdep::ssw